import * as React from 'react'
import {forwardRef} from 'react'
import {Button, CircularProgress, Icon, Theme} from '@mui/material'
import createStyles from '@mui/styles/createStyles'
import makeStyles from '@mui/styles/makeStyles'
import classNames from 'classnames'
import {ButtonProps} from '@mui/material/Button'

const useStyles = makeStyles((t: Theme) => createStyles({
  progress: {
    position: 'absolute',
    top: '50%',
    left: '50%',
    marginTop: -12,
    marginLeft: -12,
  },
  label: {
    display: 'flex',
    alignItems: 'center',
  },
  icon: {
    height: '22px !important',
    lineHeight: '22px !important',
    fontSize: '22px !important',
    marginRight: t.spacing(1)
  },
  iconAfter: {
    marginRight: 0,
    marginLeft: t.spacing(1),
  },
  labelHidden: {
    visibility: 'hidden',
  },
}))

export interface BtnProps extends ButtonProps {
  loading?: boolean
  icon?: string
  iconAfter?: string
}

export const Btn = forwardRef(({loading, children, disabled, icon, iconAfter, className, ...props}: BtnProps, ref: any) => {
  const classes = useStyles({})
  return (
    <Button
      {...props}
      className={classNames(className)}
      disabled={disabled || loading}
      ref={ref}
    >
      <div className={classNames(classes.label, loading && classes.labelHidden)}>
        {icon && <Icon className={classes.icon}>{icon}</Icon>}
        {children}
        {iconAfter && <Icon className={classNames(classes.icon, classes.iconAfter)}>{iconAfter}</Icon>}
      </div>
      {loading && <CircularProgress size={24} className={classes.progress}/>}
    </Button>
  )
})
