import * as React from 'react'
import {ReactNode} from 'react'
import { Divider, Icon, Theme } from '@mui/material';
import createStyles from '@mui/styles/createStyles';
import makeStyles from '@mui/styles/makeStyles';

const useStyles = makeStyles((t: Theme) => createStyles({
  root: {
    paddingLeft: t.spacing(2),
    [t.breakpoints.up('sm')]: {
      paddingLeft: t.spacing(3),
      paddingRight: t.spacing(3),
    },
    display: 'flex',
    alignItems: 'center',
    color: t.palette.text.secondary,
    background: t.palette.mode === 'light' ? t.palette.grey[100] : t.palette.grey[900],
    paddingRight: t.spacing(1) + 'px !important',
    order: -1, // To be positioned before loader,
    height: 48,
  },
  icon: {
    marginRight: t.spacing(2),
  },
  content: {
    flex: 1,
  },
}))

export interface PanelHeadProps {
  icon?: string;
  children?: ReactNode;
  action?: any;
  className?: string;
}

export const PanelHead = ({className, icon, children, action}: PanelHeadProps) => {
  const classes = useStyles()
  return (
    <>
      <div className={`${classes.root} ${className || ''}`}>
        {icon &&
        <Icon className={classes.icon}>{icon}</Icon>
        }
        <div className={classes.content}>{children}</div>
        <div>
          {action}
        </div>
      </div>
      <Divider/>
    </>
  )
}
