import { Theme } from '@mui/material';
import makeStyles from '@mui/styles/makeStyles';
import classNames from 'classnames'
import * as React from 'react'
import {forwardRef, HTMLProps} from 'react'
import {capitalize} from '@mui/material/utils'
import { Skeleton } from '@mui/material';

interface Props extends Omit<HTMLProps<HTMLDivElement>, 'size'> {
  bold?: boolean
  italic?: boolean
  gutterBottom?: boolean
  block?: boolean
  skeleton?: boolean | number | string
  size?: 'big' | 'title' | 'small'
  color?: 'primary' | 'secondary' | 'disabled' | 'hint' | 'default' | 'error'
  uppercase?: boolean
  truncate?: boolean,
  noWrap?: boolean
  link?: boolean
}

const useStyles = makeStyles((t: Theme) => ({
  root: {
    display: 'inline',
    lineHeight: '1.5',
  },
  block: {
    display: 'block',
  },
  bold: {
    fontWeight: t.typography.fontWeightMedium,
  },
  title: {
    fontSize: '1.30rem',
  },
  big: {
    fontSize: '1.10rem',
  },
  small: {
    fontSize: '0.85rem',
  },
  italic: {
    fontStyle: 'italic',
  },
  gutterBottom: {
    marginBottom: t.spacing(1),
  },
  colorPrimary: {
    color: t.palette.primary.main,
  },
  colorSecondary: {
    color: t.palette.secondary.main,
  },
  colorDisabled: {
    color: t.palette.text.disabled,
  },
  colorHint: {
    color: t.palette.text.secondary,
  },
  colorError: {
    color: t.palette.error.main,
  },
  colorDefault: {
    color: t.palette.text.primary,
  },
  link: {
    color: t.palette.primary.main,
  },
  skeleton: {
    display: 'inline-block',
  },
  uppercase: {
    textTransform: 'uppercase' as any,
  },
  noWrap: {
    whiteSpace: 'nowrap' as any,
  },
  truncate: {
    whiteSpace: 'nowrap' as any,
    textOverflow: 'ellipsis',
    overflow: 'hidden',
  },
}))

export const Txt = forwardRef(({
  skeleton,
  children,
  gutterBottom,
  block,
  bold,
  size,
  link,
  italic,
  color,
  uppercase,
  truncate,
  noWrap,
  className,
  ...otherProps
}: Props, ref: any) => {
  const css = useStyles()
  const classes = classNames(
    css.root,
    gutterBottom && css.gutterBottom,
    bold && css.bold,
    (() => {
      switch (size) {
        case 'big':
          return css.big
        case 'title':
          return css.title
        case 'small':
          return css.small
      }
    })(),
    italic && css.italic,
    block && css.block,
    link && css.link,
    uppercase && css.uppercase,
    truncate && css.truncate,
    noWrap && css.noWrap,
    // @ts-ignore
    color && css['color' + capitalize(color)],
    className,
  )
  return (
    <div className={classes} {...otherProps} ref={ref}>
      {skeleton ? (
        <Skeleton className={css.skeleton} width={isNaN(skeleton as any) ? '80%' : skeleton as number}/>
      ) : (
        children
      )}
    </div>
  )
})
